==> pdfbox-2.0.32-src.zip: pdfbox-2.0.32/pdfbox/src/test/java/org/apache/pdfbox/pdmodel/common/PDIntegerNameTreeNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.pdfbox.pdmodel.common;

import java.io.IOException;
import org.apache.pdfbox.cos.COSBase;
import org.apache.pdfbox.cos.COSDictionary;
import org.apache.pdfbox.cos.COSInteger;

/**
 * todo: JavaDoc
 *
 * @author John Hewson
 */
public class PDIntegerNameTreeNode extends PDNameTreeNode<COSInteger>
{
    /**
     * Constructor.
     */
    public PDIntegerNameTreeNode()
    {
        super();
    }

    /**
     * Constructor.
     *
     * @param dic The COS dictionary.
     */
    public PDIntegerNameTreeNode(COSDictionary dic)
    {
        super(dic);
    }

    @Override
    protected COSInteger convertCOSToPD(COSBase base) throws IOException
    {
        return (COSInteger)base;
    }

    @Override
    protected PDIntegerNameTreeNode createChildNode( COSDictionary dic )
    {
        return new PDIntegerNameTreeNode(dic);
    }
}

==> pdfbox-2.0.35-src.zip: pdfbox-2.0.35/pdfbox/src/test/java/org/apache/pdfbox/pdmodel/common/PDIntegerNameTreeNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.pdfbox.pdmodel.common;

import java.io.IOException;
import org.apache.pdfbox.cos.COSBase;
import org.apache.pdfbox.cos.COSDictionary;
import org.apache.pdfbox.cos.COSInteger;

/**
 * todo: JavaDoc
 *
 * @author John Hewson
 */
public class PDIntegerNameTreeNode extends PDNameTreeNode<COSInteger>
{
    /**
     * Constructor.
     */
    public PDIntegerNameTreeNode()
    {
    }

    /**
     * Constructor.
     *
     * @param dic The COS dictionary.
     */
    public PDIntegerNameTreeNode(COSDictionary dic)
    {
        super(dic);
    }

    @Override
    protected COSInteger convertCOSToPD(COSBase base) throws IOException
    {
        if (base != null && !(base instanceof COSInteger))
        {
            throw new IOException("integer expected here, but got " + base);
        }
        return (COSInteger)base;
    }

    @Override
    protected PDIntegerNameTreeNode createChildNode( COSDictionary dic )
    {
        return new PDIntegerNameTreeNode(dic);
    }
}
